@@ -27,6 +27,18 @@
 --
 --
 -- $Log: computer.c,v $
+-- Revision 1.31  2007/10/07 03:51:35  jsedwards
+-- Added new function 'space_available' and don't execute command if it
+-- returns false.
+--
+-- Revision 1.30  2007/09/02 19:45:31  jsedwards
+-- Added calls to set the block estimate.
+--
+-- Revision 1.29  2007/08/12 20:45:00  jsedwards
+-- Change all of the "Encryption Level" stuff to "Security Level" because it
+-- doesn't really change the encryption at all, all it does is change the
+-- randomization of where objects are stored.
+--
 -- Revision 1.28  2007/07/12 03:12:42  jsedwards
 -- Add a command to add a birthday to a person.
 --
@@ -248,6 +260,19 @@ static bool is_what_is_number(char* command)
 }
 
 
+static bool space_available(uint32 estimated_blocks)
+{
+    if (!nwos_check_blocks_available(estimated_blocks))
+    {
+	printf("Command not completed\n");
+
+	return false;
+    }
+
+    return true;
+}
+
+
 void execute_command(char *command)
 {
     char* ptr1;
@@ -257,7 +282,10 @@ void execute_command(char *command)
 
     if (strcasecmp(command, "add person") == 0)
     {
-	nwos_add_person();
+	if (space_available(36))
+	{
+	    nwos_add_person();
+	}
     }
     else if (strcasecmp(command, "list persons") == 0)
     {
@@ -273,7 +301,10 @@ void execute_command(char *command)
     }
     else if (strcasecmp(command, "add account") == 0)
     {
-	nwos_add_account();
+	if (space_available(12))
+	{
+	    nwos_add_account();
+	}
     }
     else if (strcasecmp(command, "list accounts") == 0)
     {
@@ -308,8 +339,12 @@ void execute_command(char *command)
     }
     else if (strcasecmp(command, "add city") == 0)
     {
-	ObjRef  city_ref;
-	nwos_add_city(&city_ref);
+	if (space_available(8))
+	{
+	    ObjRef city_ref;
+
+	    nwos_add_city(&city_ref);
+	}
     }
     else if (strstr(command, " birthday is ") != NULL)
     {
@@ -325,7 +360,10 @@ void execute_command(char *command)
 	}
 	*ptr1 = '\0';    /* terminate the name here */
 
-	nwos_add_birthday(command, ptr2);
+	if (space_available(4))
+	{
+	    nwos_add_birthday(command, ptr2);
+	}
     }
     else if (strstr(command, " mobile phone is ") != NULL)
     {
@@ -341,7 +379,10 @@ void execute_command(char *command)
 	}
 	*ptr1 = '\0';    /* terminate the name here */
 
-	nwos_add_mobile_phone(command, ptr2);
+	if (space_available(4))
+	{
+	    nwos_add_mobile_phone(command, ptr2);
+	}
     }
     else if (is_what_is_number(command))
     {
@@ -378,7 +419,7 @@ int main(int argc, char* argv[])
 
     nwos_set_root_object(&root_object_ref);
 
-    nwos_set_encryption_level(Encryption_Extreme);
+    nwos_set_security_level(Security_Extreme);
 
     if (argc == 1)   /* nothing on the command line */
     {
