@@ -27,6 +27,14 @@
 --
 --
 -- $Log: diff_compressed.c,v $
+-- Revision 1.14  2007/11/17 21:26:57  jsedwards
+-- Fix increment in version_string_to_int function so it isn't an infinite loop.
+--
+-- Revision 1.13  2007/11/17 20:00:09  jsedwards
+-- Changed to detect if the files are older than version 0023 (where the
+-- reference id's wrapped around the storage) and insert the next block in
+-- bytes 0 to 3 of the block.  If they are not old leave zeros in bytes 0 to 3.
+--
 -- Revision 1.12  2007/07/01 19:44:11  jsedwards
 -- Upgrade to GPLv3.
 --
@@ -70,6 +78,7 @@
 --
 */
 
+#include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -77,12 +86,33 @@
 
 #include "objectify_private.h"
 
+
 uint32 convert_4_uint8_to_uint32(uint8 byte[4])
 {
   return ((uint32)byte[0] << 24) | ((uint32)byte[1] << 16) | ((uint32)byte[2] << 8) | (uint32)byte[3];
 }
 
 
+static int version_string_to_int(char string[4])
+{
+    int i;
+    int result = 0;
+
+    for (i = 0; i < 4; i++) if (string[i] != '0') break;
+
+    while (i < 4)
+    {
+	if (!isdigit(string[i])) return -1;
+
+	result = result * 10 + string[i] - '0';
+
+	i++;
+    }
+
+    return result;
+}
+
+
 int main(int argc, char* argv[])
 {
     FILE* fp1;
@@ -100,6 +130,9 @@ int main(int argc, char* argv[])
     Disk_Header header1;
     Disk_Header header2;
     Disk_Header_0021 old_header;
+    bool wrapped_file = false;     /* true if older file that wasn't sequencial */
+    int header1_version;
+    int header2_version;
 
 
     if (argc != 3 && argc != 4)
@@ -222,6 +255,34 @@ int main(int argc, char* argv[])
     }
       }
 
+    header1_version = version_string_to_int(header1.version_string);
+
+    if (header1_version < 1)
+    {
+	fprintf(stderr, "Invalid version string in file: %s\n", argv[1]);
+	exit(1);
+    }
+
+    header2_version = version_string_to_int(header2.version_string);
+
+    if (header2_version < 1)
+    {
+	fprintf(stderr, "Invalid version string in file: %s\n", argv[2]);
+	exit(1);
+    }
+
+    if (header1_version < 23 && header2_version < 23)
+    {
+	wrapped_file = true;   /* it's an old file */
+    }
+    else if (header1_version < 23 || header2_version < 23)
+    {
+	fprintf(stderr, "ERROR: '%s' is an old wrapped file, but file '%s' is not, cannot diff!\n",
+		header1_version < 23 ? argv[1] : argv[2],
+		header1_version < 23 ? argv[2] : argv[1]);
+	exit(1);
+    }
+
     if (argc == 4)
     {
 	fp3 = fopen(argv[3], "w");
@@ -318,11 +379,13 @@ int main(int argc, char* argv[])
 
 	    if (fp3 != NULL)   /* write the new block */
 	    {
-		/* write the id of the next old block into bytes 0-3 of the new block */
-		buf2a[0] = buf1a[4];
-		buf2a[1] = buf1a[5];
-		buf2a[2] = buf1a[6];
-		buf2a[3] = buf1a[7];
+		if (wrapped_file)   /* write the id of the next old block into bytes 0-3 of the new block */
+		{
+		    buf2a[0] = buf1a[4];
+		    buf2a[1] = buf1a[5];
+		    buf2a[2] = buf1a[6];
+		    buf2a[3] = buf1a[7];
+		}
 
 		write3 = fwrite(buf2a, 1, sizeof(buf2a), fp3);
 
