@@ -1,23 +1,47 @@
-/*             This file is part of the New World OS project
+/*
+--             This file is part of the New World OS project
 --                Copyright (C) 2006, 2007  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
 --
--- NWOS is free software;  you can redistribute it and/or modify it under the
--- terms of the GNU General Public License  as published by the Free Software
--- Foundation; either version 2, or (at your option) any later version.  This
--- software is distributed with the hope that it will be useful,  but WITHOUT
--- ANY WARRANTY;  without  even the  implied warranty  of MERCHANTABILITY  or
--- FITNESS FOR A PARTICULAR PURPOSE.   See the GNU General Public License for
--- more  details.  You should have received a copy  of the GNU General Public
--- License along with this package;  see the file LICENSE.  If not, write to:
+--   This program is free software: you can redistribute it and/or modify
+--   it under the terms of the GNU General Public License as published by
+--   the Free Software Foundation, either version 3 of the License, or
+--   (at your option) any later version.
+--
+--   This program is distributed in the hope that it will be useful,
+--   but WITHOUT ANY WARRANTY; without even the implied warranty of
+--   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+--   GNU General Public License for more details.
+--
+--   You should have received a copy of the GNU General Public License
+--   along with this program, in the file LICENSE.  If not, see 
+--   <http://www.gnu.org/licenses/>.
+--
+--   You can also contact me via paper mail at:
+--
+--      QRW Software
+--      P.O. Box 27511
+--      Salt Lake City, UT 84127-0511, USA.
 --
---      Free Software Foundation, Inc.
---      59 Temple Place - Suite 330
---      Boston, MA 02111-1307, USA.
 --
 -- $Log: disc_list.c,v $
+-- Revision 1.15  2007/10/07 03:43:50  jsedwards
+-- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
+-- changed to exit gracefully if not enough space available.
+--
+-- Revision 1.14  2007/09/02 19:47:25  jsedwards
+-- Added call to set the block estimate.
+--
+-- Revision 1.13  2007/08/12 20:45:00  jsedwards
+-- Change all of the "Encryption Level" stuff to "Security Level" because it
+-- doesn't really change the encryption at all, all it does is change the
+-- randomization of where objects are stored.
+--
+-- Revision 1.12  2007/07/01 19:44:11  jsedwards
+-- Upgrade to GPLv3.
+--
 -- Revision 1.11  2007/06/13 21:15:03  jsedwards
 -- Comment out debugging print statement accidentally left in.
 --
@@ -173,7 +197,15 @@ int main(int argc, char* argv[])
 
     nwos_set_root_object(&root_object_ref);
 
-    nwos_set_encryption_level(Encryption_Very_Low);
+    nwos_set_security_level(Security_Very_Low);
+
+    if (!nwos_check_blocks_available(2 + num_files * 12)) /* 1 file = 14, 2 files = 26, 3 files = 38... */
+    {
+	fprintf(stderr, "Cannot add disc_list!\n");
+	nwos_terminate_objectify();
+	exit(1);
+    }
+
 
     /*******************/
     /* Get the disc id */
