@@ -27,6 +27,19 @@
 --
 --
 -- $Log: disk_io.c,v $
+-- Revision 1.54  2007/11/13 15:01:33  jsedwards
+-- Added #ifndef NO_BACKUP around calls to backup module.  This way we don't
+-- have to include it when compiling export_c_structs.
+--
+-- Revision 1.53  2007/11/09 15:53:47  jsedwards
+-- Moved variables and code that deal with backup file to new file backup.c.
+--
+-- Revision 1.52  2007/11/08 12:32:57  jsedwards
+-- Split code to finish writing the backup file out into a separate function.
+--
+-- Revision 1.51  2007/11/08 05:23:17  jsedwards
+-- Added code to create and write backup file.
+--
 -- Revision 1.50  2007/11/03 15:15:10  jsedwards
 -- Fix to handle the case where the block_estimate is smaller than what will
 -- fit in one chunk.
@@ -504,6 +517,7 @@ void nwos_initialize_disk_io(StorageType type, char* path)
     uint16 right;
     uint16 save;
 
+
     /* make sure the storage is something we can deal with */
     assert(type == Drive_Or_Partition_RO || type == Drive_Or_Partition_RW || 
 	   type == Sparse_File_RO || type == Sparse_File_RW || type == Compressed_File_RO);
@@ -727,6 +741,15 @@ void nwos_initialize_disk_io(StorageType type, char* path)
 
 	snprintf(log_msg, sizeof(log_msg), "   private blocks: %9u  used: %9u", nwos_total_private_blocks, nwos_used_private_blocks);
 	nwos_log(log_msg);
+
+#ifndef NO_BACKUP
+	/* Do a backup file? */
+
+	if (BACKUP_LOCATION != NULL && !read_only)
+	{
+	    nwos_initialize_backup(BACKUP_LOCATION, &disk_header);
+	}
+#endif
     }
 }
 
@@ -837,16 +860,18 @@ void nwos_terminate_disk_io()
     if (close(private_file_desc) < 0)
     {
 	perror(nwos_private_path);
-	exit(1);
     }
 
     private_file_desc = 0;
     nwos_private_path = NULL;
 
+#ifndef NO_BACKUP
+    nwos_terminate_backup(modified, &disk_header);
+#endif
+
     if (close(public_file_desc) < 0)
     {
 	perror(nwos_public_path);
-	exit(1);
     }
 
     public_file_desc = 0;
@@ -2269,6 +2294,10 @@ void nwos_write_block(ObjRef* ref, uint8 block[FILE_BLOCK_SIZE])
 	exit(1);
     }
 
+#ifndef NO_BACKUP
+    nwos_backup_write_block(block);
+#endif
+
     modified = true;
 #endif
 }
