@@ -27,6 +27,10 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.24  2007/11/20 06:07:38  jsedwards
+-- Fix to close backup file after initialize_objectify so no backup will be
+-- written while restoring.
+--
 -- Revision 1.23  2007/08/10 00:04:06  jsedwards
 -- Removed defintion of _LARGEFILE64_SOURCE, now using _FILE_OFFSET_BITS=64.
 --
@@ -194,6 +198,7 @@ int main(int argc, char* argv[])
 
     nwos_initialize_objectify(NULL, 0, 0, DEFAULT_TYPE_RW, DEFAULT_FILE);
 
+    nwos_terminate_backup(false, NULL);   /* don't create a backup file */
 
     /* Verify that is what s/he really wants to do */
 
