@@ -27,6 +27,18 @@
 --
 --
 -- $Log: log_disc.c,v $
+-- Revision 1.30  2007/10/07 03:43:50  jsedwards
+-- Renamed 'nwos_set_block_estimate' to 'nwos_check_blocks_available' and
+-- changed to exit gracefully if not enough space available.
+--
+-- Revision 1.29  2007/09/02 19:47:25  jsedwards
+-- Added call to set the block estimate.
+--
+-- Revision 1.28  2007/08/12 20:45:00  jsedwards
+-- Change all of the "Encryption Level" stuff to "Security Level" because it
+-- doesn't really change the encryption at all, all it does is change the
+-- randomization of where objects are stored.
+--
 -- Revision 1.27  2007/07/12 16:00:04  jsedwards
 -- Give 'binder' an illegal initial value so compiler on FreeBSD won't complain.
 --
@@ -256,7 +268,14 @@ int main(int argc, char* argv[])
 
     nwos_set_root_object(&root_object_ref);
 
-    nwos_set_encryption_level(Encryption_Very_Low);
+    nwos_set_security_level(Security_Very_Low);
+
+    if (!nwos_check_blocks_available(14))   /* 14 if new storage location is created, normally just 2 */
+    {
+	fprintf(stderr, "Cannot create new storage location!\n");
+	nwos_terminate_objectify();
+	exit(1);
+    }
 
     if (nwos_find_private_class_definition("STORAGE LOCATION", &location_class_ref))
     {
