@@ -27,6 +27,9 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.138  2007/11/24 16:59:42  jsedwards
+-- Fixed to compile correctly when compiled with PUBLIC_MODE defined.
+--
 -- Revision 1.137  2007/10/25 03:22:20  jsedwards
 -- Move 'last_ref' to disk_io.c.
 --
@@ -1169,7 +1172,7 @@ Reference_Type nwos_reference_type(ObjRef* ref)
 }
 
 
-
+#ifndef PUBLIC_MODE
 void nwos_set_security_level(Security_Level new_level)
 {
     bool Security_Not_Set = false;
@@ -1211,6 +1214,7 @@ void nwos_set_security_level(Security_Level new_level)
 
     nwos_restart_id_generation();   /* clear last_ref so this security level starts fresh */
 }
+#endif
 
 
 void nwos_generate_new_id(ObjRef* ref)
@@ -1390,7 +1394,9 @@ void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t si
     assert(nwos_read_block(ref, buffer2));
 
     assert(block_contains_object(buffer2, ref));
-
+#ifdef PUBLIC_MODE
+    memcpy(object, buffer2, size);
+#else
 #ifdef DEBUG_ENCRYPTION
     compare_bufs(buffer2, save_encrypted, "Encrypted");
 #endif
@@ -1437,6 +1443,7 @@ void nwos_read_object_from_disk_and_decrypt(ObjRef* ref, void* object, size_t si
 #ifdef DEBUG_ENCRYPTION
     compare_bufs(ptrobj, save_unencrypted, "Unencrypted");
 #endif
+#endif
 }
 
 
@@ -1756,6 +1763,11 @@ void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t siz
     memcpy(save_unencrypted, object, FILE_BLOCK_SIZE);
 #endif
 
+#ifdef PUBLIC_MODE
+    memset(buffer2, 0, FILE_BLOCK_SIZE);
+    memcpy(buffer2, object, size);
+#else
+
 #ifdef DISABLE_SECURITY_FEATURES    /* always do the unencryped code */
     if (true)
 #else
@@ -1793,6 +1805,7 @@ void nwos_write_object_to_disk_and_encrypt(ObjRef* ref, void* object, size_t siz
 	/* and encrypt the remainder 8 bytes at a time */
 	BF_cbc_encrypt((buffer1 + 8), (buffer2 + 8), (FILE_BLOCK_SIZE - 8), &blowfish_key, ivec, BF_ENCRYPT);
     }
+#endif
 
 #ifdef DEBUG_ENCRYPTION
     memcpy(save_encrypted, buffer2, FILE_BLOCK_SIZE);
