@@ -27,6 +27,9 @@
 --
 --
 -- $Log: objectify_private.h,v $
+-- Revision 1.59  2007/11/09 15:44:20  jsedwards
+-- Added externs for backup.c module.
+--
 -- Revision 1.58  2007/10/25 00:48:38  jsedwards
 -- Removed 'last_ref' paramter from nwos_generate_new_closely_spaced_id and
 -- nwos_generate_new_1_in_N_id.
@@ -451,6 +454,9 @@ extern char* nwos_public_path;
 extern char* nwos_private_path;
 extern void  nwos_initialize_disk_io(StorageType type, char* path);
 extern void  nwos_terminate_disk_io();
+extern void  nwos_initialize_backup(char* path, Disk_Header* disk_header);
+extern void  nwos_terminate_backup(bool modified, Disk_Header* disk_header);
+extern void  nwos_backup_write_block(uint8 block[FILE_BLOCK_SIZE]);
 extern void  nwos_set_allocation_parameters(uint32 density, int32 skip_backward, int32 skip_forward);
 extern void  nwos_allocate_new_chunk(uint32 ref);
 extern void nwos_generate_new_closely_spaced_id(int density, ObjRef* new_ref);
